@@ -18,6 +18,8 @@
 #     arraycrop (of zoiets)
 # 
 
+from numpy import *
+from sciproc import arraysel
 
 
 # apply a function for each element along various axis
