@@ -28,9 +28,10 @@ def cosel(coords = None, outcoords = None):
     return selout
 
 # someone may want to do this (if it's possible) instead of interpolation
-def datacosel(indata, coords = None outcoords = None, \
+def datacosel(indata, coords = None, outcoords = None, \
               start= None,end= None,step = None,  \
               outstart = None, outend = None, outstep = None):
+    # if coordinates not given, make it from the start, end, step arguments
     if (coords == None):
         coords = dtrange(start, end, step)
     if (outcoords == None):
